@@ -1,28 +1,25 @@
-/* 
-** Mount the davfs file system.
- */
+/*  mount_davfs.h: structure to collect arguments and options.
+    Copyright (C) 2006, 2007, 2008, 2009 Werner Baumann
 
-/*
- *  This file is part of davfs2.
- *
- *  davfs2 is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  davfs2 is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with davfs2; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
+    This file is part of davfs2.
+
+    davfs2 is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    davfs2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with davfs2; if not, write to the Free Software Foundation,
+    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 
-#ifndef __MOUNT_DAVFS_H__
-#define __MOUNT_DAVFS_H__
+#ifndef DAV_MOUNT_DAVFS_H
+#define DAV_MOUNT_DAVFS_H
 
 
 /* Data Types */
@@ -40,6 +37,7 @@ typedef struct {
     char *conf;               /* Command line */
     /* Mount options */
     int user;                 /* Command line */
+    int users;                 /* Command line */
     int netdev;               /* Command line */
     unsigned long int mopts;  /* Command line */
     char *add_mopts;
@@ -69,14 +67,13 @@ typedef struct {
     char *p_passwd;           /* User secrets file, system secrets file */
     int useproxy;             /* User config file, sys conf f., command line */
     int askauth;              /* User config file, sys conf f., command line */
-    int displayname;          /* User config file, system config file */
     int locks;                /* User config file, sys conf f., command line */
     char * lock_owner;        /* User config file, system config file */
     time_t lock_timeout;      /* User config file, system config file */
     time_t lock_refresh;      /* User config file, system config file */
     int expect100;            /* User config file, system config file */
     int if_match_bug;         /* User config file, system config file */
-    int drop_weak_etags;    /* User config file, system config file */
+    int drop_weak_etags;      /* User config file, system config file */
     int allow_cookie;         /* User config file, system config file */
     int precheck;             /* User config file, system config file */
     int ignore_dav_header;    /* User config file, system config file */
@@ -84,6 +81,7 @@ typedef struct {
     time_t read_timeout;      /* User config file, system config file */
     time_t retry;             /* User config file, system config file */
     time_t max_retry;         /* User config file, system config file */
+    int max_upload_attempts;  /* User config file, system config file */
     char * s_charset;         /* User config file, system config file */
     char * header;            /* User config file, system config file */
     /* Cache */
@@ -94,7 +92,7 @@ typedef struct {
     size_t table_size;        /* User config file, system config file */
     time_t dir_refresh;       /* User config file, system config file */
     time_t file_refresh;      /* User config file, system config file */
-    int delay_upload;        /* User config file, system config file */
+    int delay_upload;         /* User config file, system config file */
     int gui_optimize;         /* User config file, system config file */
     /* Debugging */
     int debug;                /* User config file, system config file */
@@ -102,8 +100,8 @@ typedef struct {
 } dav_args;
 
 
-/* Public function. Just main(). */
-/*===============================*/
+/* Public functions. */
+/*===================*/
 
 /* Main launches a daemon program that runs a directory and file cache and
    is connected to the WbDAV resource and the kernel file system module.
@@ -146,6 +144,16 @@ typedef struct {
      loop will terminate gracefully.
    - The close functions of the modules are called, that will clean up the
      cache, save cached information if neccessary and close the connections. */
-int main(int argc, char *argv[]);
+int
+main(int argc, char *argv[]);
 
-#endif
+
+/* Prints prompt to stdout and reads a line from stdin.
+   Echoing the user input to stdout is prohibited.
+   A trailing newline is removed.
+   return value : the user input. */
+char *
+dav_user_input_hidden(const char *prompt);
+
+
+#endif /* DAV_MOUNT_DAVFS_H */
