@@ -1,24 +1,21 @@
-/* 
-** Unmount the davfs file system.
- */
+/*  umount_davfs.c: unmount the davfs file system.
+    Copyright (C) 2006, 2007, 2008, 2009 Werner Baumann
 
-/*
- *  This file is part of davfs2.
- *
- *  davfs2 is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  davfs2 is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with davfs2; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
+    This file is part of davfs2.
+
+    davfs2 is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    davfs2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with davfs2; if not, write to the Free Software Foundation,
+    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 
 #include "config.h"
@@ -26,25 +23,33 @@
 #include <error.h>
 #include <errno.h>
 #include <getopt.h>
+#ifdef HAVE_LIBINTL_H
+#include <libintl.h>
+#endif
+#ifdef HAVE_LOCALE_H
 #include <locale.h>
+#endif
 #include <stdio.h>
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
 #include <string.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-
-#ifdef ENABLE_NLS
-#   include <libintl.h>
-#   define _(String) gettext(String)
-#else
-#   define _(String) String
-#   define textdomain(Domainname)
-#   define bindtextdomain(Domainname, Dirname)
 #endif
 
 #include <ne_string.h>
 
 #include "defaults.h"
 
+#ifdef ENABLE_NLS
+#define _(String) gettext(String)
+#else
+#define _(String) String
+#define textdomain(Domainname)
+#define bindtextdomain(Domainname, Dirname)
+#endif
+
 
 /* This is lazy programming. All the dirty work is left to the real umount
    program, while we just sit and wait for mount.davfs to terminate.
@@ -57,8 +62,9 @@
    mount.davfs process terminates, it will return.
    If it can't identify the mount.davfs process, it will call umount -i anyway,
    but warn the user. */
-int main(int argc, char *argv[]) {
-
+int
+main(int argc, char *argv[])
+{
     setuid(getuid());
     setgid(getgid());
 
@@ -78,7 +84,7 @@ int main(int argc, char *argv[]) {
     while (o != -1) {
         switch (o) {
         case 'V':
-            printf("%s  <%s>\n\n", PACKAGE_STRING, DAV_HOME);
+            printf("%s  <%s>\n\n", PACKAGE_STRING, PACKAGE_BUGREPORT);
             printf(_("This is free software; see the source for copying "
                      "conditions.  There is NO\n"
                      "warranty; not even for MERCHANTABILITY or FITNESS "
@@ -115,9 +121,9 @@ int main(int argc, char *argv[]) {
         error(EXIT_FAILURE, 0, _("too many arguments"));
 
     char *mpoint = canonicalize_file_name(argv[optind]);
-    if (mpoint == NULL)
+    if (!mpoint)
         mpoint = argv[optind];
-    if (mpoint == NULL || *mpoint != '/')
+    if (!mpoint || *mpoint != '/')
         error(EXIT_FAILURE, 0, _("can't determine mount point"));
 
     char *m = mpoint;
@@ -125,7 +131,7 @@ int main(int argc, char *argv[]) {
         m++;
     char *mp = ne_strdup(m);
     m = strchr(mp, '/');
-    while (m != NULL) {
+    while (m) {
         *m = '-';
         m = strchr(mp, '/');
     }
@@ -136,8 +142,7 @@ int main(int argc, char *argv[]) {
 
     char *pid = NULL;
     FILE *file = fopen(pidfile, "r");
-    if (file == NULL || fscanf(file, "%a[0-9]", &pid) != 1
-            || pid == NULL) {
+    if (!file || fscanf(file, "%a[0-9]", &pid) != 1 || !pid) {
         error(0, 0,
               _("\n"
                 "  can't read PID from file %s;\n"
@@ -149,7 +154,7 @@ int main(int argc, char *argv[]) {
 
     char *ps_command = ne_concat("ps -p ", pid, NULL);
     FILE *ps_in = popen(ps_command, "r");
-    if (ps_in == NULL) {
+    if (!ps_in) {
         error(0, 0,
               _("\n"
                 "  can't read process list;\n"
@@ -162,8 +167,7 @@ int main(int argc, char *argv[]) {
     size_t n = 0;
     char *ps_line = NULL;
     while (!found && getline(&ps_line, &n, ps_in) > 0)
-        found = (strstr(ps_line, pid) != NULL
-                 && strstr(ps_line, PROGRAM_NAME) != NULL);
+        found = (strstr(ps_line, pid) && strstr(ps_line, PROGRAM_NAME));
     pclose(ps_in);
 
     if (!found) {
@@ -190,7 +194,7 @@ int main(int argc, char *argv[]) {
         fflush(stdout);
 
         ps_in = popen(ps_command, "r");
-        if (ps_in == NULL) {
+        if (!ps_in) {
             printf("\n");
             error(EXIT_FAILURE, 0, _("an error occured while waiting; "
                   "please wait for %s to terminate"), PROGRAM_NAME);
@@ -198,8 +202,7 @@ int main(int argc, char *argv[]) {
 
         found = 0;
         while (!found && getline(&ps_line, &n, ps_in) > 0)
-            found = (strstr(ps_line, pid) != NULL
-                     && strstr(ps_line, PROGRAM_NAME) != NULL);
+            found = (strstr(ps_line, pid) && strstr(ps_line, PROGRAM_NAME));
 
         pclose(ps_in);
     }
